==> graphscope_client-0.18.0a20221011-cp37-cp37m-macosx_10_9_x86_64.whl: graphscope/analytical/app/wcc.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright 2020 Alibaba Group Holding Limited. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from graphscope.framework.app import AppAssets
from graphscope.framework.app import not_compatible_for
from graphscope.framework.app import project_to_simple

__all__ = ["wcc"]


@project_to_simple
@not_compatible_for("arrow_property", "dynamic_property")
def wcc(graph):
    """Evaluate weakly connected components on the `graph`.

    Args:
        graph (:class:`graphscope.Graph`): A simple graph.

    Returns:
        :class:`graphscope.framework.context.VertexDataContextDAGNode`:
            A context with each vertex assigned with the component ID, evaluated in eager mode.

    Examples:

    .. code:: python

        >>> import graphscope
        >>> from graphscope.dataset import load_p2p_network
        >>> sess = graphscope.session(cluster_type="hosts", mode="eager")
        >>> g = load_p2p_network(sess)
        >>> # project to a simple graph (if needed)
        >>> pg = g.project(vertices={"host": ["id"]}, edges={"connect": ["dist"]})
        >>> c = graphscope.wcc(pg)
        >>> sess.close()
    """
    if graph.oid_type == "std::string":
        raise RuntimeError("Wcc algorithm cannot run on the graph with 'string' type")
    return AppAssets(algo="wcc", context="vertex_data")(graph)

==> graphscope_client-0.18.0-1-cp37-cp37m-macosx_10_9_x86_64.whl: graphscope/analytical/app/wcc.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Copyright 2020 Alibaba Group Holding Limited. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import logging

from graphscope.framework.app import AppAssets
from graphscope.framework.app import not_compatible_for
from graphscope.framework.app import project_to_simple

__all__ = ["wcc", "wcc_auto", "wcc_projected"]

logger = logging.getLogger("graphscope")


@project_to_simple
@not_compatible_for("arrow_property", "dynamic_property")
def wcc(graph):
    """Evaluate weakly connected components on the `graph`.
    This is an optimized version of WCC.
    Note this cannot be compiled against a property graph that has multiple labels.

    Args:
        graph (:class:`graphscope.Graph`): A simple graph.

    Returns:
        :class:`graphscope.framework.context.VertexDataContextDAGNode`:
            A context with each vertex assigned with the component ID, evaluated in eager mode.

    Examples:

    .. code:: python

        >>> import graphscope
        >>> from graphscope.dataset import load_p2p_network
        >>> sess = graphscope.session(cluster_type="hosts", mode="eager")
        >>> g = load_p2p_network(sess)
        >>> # project to a simple graph (if needed)
        >>> pg = g.project(vertices={"host": ["id"]}, edges={"connect": ["dist"]})
        >>> c = graphscope.wcc(pg)
        >>> sess.close()
    """
    cmake_extra_options = None
    if graph.oid_type == "std::string":
        logger.warning(
            "WCC algorithm will output int value as component ID on graphs that has 'string' type as ID"
        )
        cmake_extra_options = "-DWCC_USE_GID=ON"
    return AppAssets(
        algo="wcc", context="vertex_data", cmake_extra_options=cmake_extra_options
    )(graph)


@project_to_simple
@not_compatible_for("arrow_property", "dynamic_property")
def wcc_projected(graph):
    """Evaluate weakly connected components on the `graph`.
    This is a naive version of WCC.

    Args:
        graph (:class:`graphscope.Graph`): A simple graph.

    Returns:
        :class:`graphscope.framework.context.VertexDataContextDAGNode`:
            A context with each vertex assigned with the component ID, evaluated in eager mode.

    Examples:

    .. code:: python

        >>> import graphscope
        >>> from graphscope.dataset import load_p2p_network
        >>> sess = graphscope.session(cluster_type="hosts", mode="eager")
        >>> g = load_p2p_network(sess)
        >>> # project to a simple graph (if needed)
        >>> pg = g.project(vertices={"host": ["id"]}, edges={"connect": ["dist"]})
        >>> c = graphscope.wcc_projected(pg)
        >>> sess.close()
    """
    return AppAssets(algo="wcc_projected", context="vertex_data")(graph)


@project_to_simple
@not_compatible_for("arrow_property", "dynamic_property")
def wcc_auto(graph):
    """Evaluate weakly connected components on the `graph`.
    This is an auto parallel version of WCC.

    Args:
        graph (:class:`graphscope.Graph`): A simple graph.

    Returns:
        :class:`graphscope.framework.context.VertexDataContextDAGNode`:
            A context with each vertex assigned with the component ID, evaluated in eager mode.

    Examples:

    .. code:: python

        >>> import graphscope
        >>> from graphscope.dataset import load_p2p_network
        >>> sess = graphscope.session(cluster_type="hosts", mode="eager")
        >>> g = load_p2p_network(sess)
        >>> # project to a simple graph (if needed)
        >>> pg = g.project(vertices={"host": ["id"]}, edges={"connect": ["dist"]})
        >>> c = graphscope.wcc_auto(pg)
        >>> sess.close()
    """
    return AppAssets(algo="wcc_auto", context="vertex_data")(graph)
